@@ -21,7 +21,12 @@ window.unifiConfig = {
 };
 
 window.unifiConstant = {
-  GoogleMapsApiKey: 'AIzaSyDW1OnFXY2kzpH77F7fEB66WlkFRtKX3p4'
+  DISCOVERY_TOOL_KEY: 'hmpigflbjeapnknladcfphgkemopofig',
+  DISCOVERY_TOOL_LATEST_VERSION: '0.2.36',
+  GoogleMapsApiKey: '',
+  GoogleAnalyticsCloudKey: 'UA-2432820-22',
+  GoogleAnalyticsDemoKey: 'UA-2432820-34',
+  VERSION: '5.3.8.2'
 };
 
 window.webrtcConfig = {
